_AttachMixin Test

# Dijit _AttachMixin Test

This markup may have come from a server side templating engine like Catalyst. The aim is to allow us to use data-dojo-attach-* magic on the content.
Change the input value to see attach event and attach point at work.

##

You say "Hello":

This test shows an inner dijit being created with attachScope referencing its enclosing dijit.

This tests that nodes inside of data-dojo-attach-point="containerNode" are ignored

##